@@ -544,6 +544,17 @@ public:
    */
   double radius() const;
 
+  /**
+   * @return The (centroid, normal vector) pair of the best-fit plane of
+   * the atoms of the molecule.
+   */
+  std::pair<Vector3, Vector3> bestFitPlane() const;
+
+  /**
+   * @return The normal vector of the best-fit plane of some specific atoms.
+   */
+  static std::pair<Vector3, Vector3> bestFitPlane(const Array<Vector3>& pos);
+
   /**
    * Set the basis set for the molecule, note that the molecule takes ownership
    * of the object.
@@ -566,6 +577,15 @@ public:
   const UnitCell* unitCell() const { return m_unitCell; }
   /** @} */
 
+  /**
+   * The space group for this molecule. It is updated after every
+   * space group operation.
+   * @{
+   */
+  void setHallNumber(unsigned short hallNumber) { m_hallNumber = hallNumber; }
+  unsigned short hallNumber() const { return m_hallNumber; }
+  /** @} */
+
   Array<double> vibrationFrequencies() const;
   void setVibrationFrequencies(const Array<double>& freq);
   Array<double> vibrationIntensities() const;
@@ -665,6 +685,9 @@ protected:
   UnitCell* m_unitCell;
   Array<Residue> m_residues;
 
+  // This will be stored from the last space group operation
+  unsigned short m_hallNumber = 0;
+
   /** Update the graph to correspond to the current molecule. */
   void updateGraph() const;
 };
