@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "inputgeneratorwidget.h"
@@ -24,8 +13,6 @@
 #include <avogadro/qtgui/generichighlighter.h>
 #include <avogadro/qtgui/molecule.h>
 
-#include <molequeue/client/jobobject.h>
-
 #include <QtWidgets/QComboBox>
 #include <QtWidgets/QDoubleSpinBox>
 #include <QtWidgets/QFileDialog>
@@ -45,8 +32,6 @@
 namespace Avogadro {
 namespace MoleQueue {
 
-using ::MoleQueue::JobObject;
-
 InputGeneratorWidget::InputGeneratorWidget(QWidget* parent_)
   : QWidget(parent_), m_ui(new Ui::InputGeneratorWidget), m_molecule(nullptr),
     m_updatePending(false), m_batchMode(false), m_inputGenerator(QString())
@@ -98,7 +83,7 @@ bool InputGeneratorWidget::configureBatchJob(BatchJob& batch) const
   if (mqOpts.empty())
     return false;
 
-  MoleQueue::JobObject job;
+  JobObject job;
   job.fromJson(mqOpts);
 
   QJsonObject calcOpts;
@@ -625,7 +610,7 @@ QJsonObject InputGeneratorWidget::promptForBatchJobOptions() const
   int numCores =
     optionString("Processor Cores", coresString) ? coresString.toInt() : 1;
 
-  MoleQueue::JobObject job;
+  JobObject job;
   job.setProgram(m_inputGenerator.displayName());
   job.setValue("numberOfCores", numCores);
 
