@@ -22,7 +22,7 @@
 #include <avogadro/qtgui/fileformatdialog.h>
 #include <avogadro/qtgui/molecule.h>
 
-#include <molequeue/client/jobobject.h>
+#include <avogadro/molequeue/client/jobobject.h>
 
 #include <QtCore/QDebug>
 
@@ -35,7 +35,7 @@ class Molecule;
 }
 namespace QtPlugins {
 
-using ::MoleQueue::JobObject;
+using MoleQueue::JobObject;
 
 GamessInput::GamessInput(QObject* parent_)
   : ExtensionPlugin(parent_), m_action(new QAction(this)), m_molecule(nullptr),
@@ -60,7 +60,7 @@ QList<QAction*> GamessInput::actions() const
 QStringList GamessInput::menuPath(QAction*) const
 {
   QStringList path;
-  path << tr("&Quantum") << tr("Input Generators");
+  path << tr("&Input");
   return path;
 }
 
@@ -112,8 +112,8 @@ void GamessInput::menuActivated()
 {
   if (!m_dialog) {
     m_dialog = new GamessInputDialog(qobject_cast<QWidget*>(parent()));
-    connect(m_dialog, SIGNAL(openJobOutput(MoleQueue::JobObject)), this,
-            SLOT(openJobOutput(MoleQueue::JobObject)));
+    connect(m_dialog, SIGNAL(openJobOutput(Avogadro::MoleQueue::JobObject)), this,
+            SLOT(openJobOutput(Avogadro::MoleQueue::JobObject)));
   }
   m_dialog->setMolecule(m_molecule);
   m_dialog->show();
